@@ -1,4 +1,4 @@
-#' Visualization of Shapley values from the BARP model
+#' Visualization of Shapley Values from the BARP Model
 #'
 #'
 #' This function is implemented to visualize the computed Shapley values in 
@@ -12,6 +12,7 @@
 #' \code{"obs"} represents the average based on observations (#post by #variable),
 #' while \code{"post"} represents the average based on posterior samples (#obs by #variable).
 #' If \code{"both"} is entered, calculations are performed based on both observation and posterior sample criteria.
+#' If no value is specified, "both" is used as the default.
 #' @param title The title of the plot, with a default value of \code{NULL}.
 #' @param type \code{"bar"} represents a bar chart that includes the average contribution of each variable,
 #'  while \code{"bee"} represents a summary plot, allowing you to determine the graph's format.
@@ -36,16 +37,37 @@
 
 plot.Explainbarp <- function(x, average = NULL, type = NULL,  num_post= NULL,
                              plot.flag=TRUE, adjust= FALSE,  probs=0.95, title=NULL,geo.unit=NULL,geo.id=NULL,...){
+  
+  if (!inherits(x, "Explainbarp") ) {
+    stop("The input object must be of class 'Explainbarp'.")
+    return(invisible(NULL))
+  } else if (missing(x) ) {
+    stop("The object containing the Shapley values of models obtained from the 'Explain' function is missing.")
+    return(invisible(NULL))
+  }
+  
   object <- x;
   value <- variable <- n <- Average_re <- 0;
-  geo_check <- str_split(colnames(object $ newdata), paste0( geo.unit,"_"),simplify = T)[,2]
-  index <- which (object $ newdata [,  which(geo_check==geo.id)] == 1 )
+  geo_check <- str_split(colnames(object$newdata), paste0( geo.unit,"_"),simplify = T)[,2]
+  index <- which (object$newdata [, which(geo_check==geo.id)] == 1 )
+  
+  
+  
+  if (isFALSE (adjust) & is.null(average)){
+    warning("By default, a plot of type 'both' is printed.\n",
+            "If you want to calculate the average based on observations, enter 'obs'.\n",
+            "If you want to calculate the average based on the posterior sample, enter 'post'.\n",
+            "To compare the results based on observation and posterior sample, enter 'both'.",call. = FALSE)
+    
+    average <- "both"
+  }  
+    
   
   if(isTRUE (adjust)) {
     
-    baseline  <-  object $fnull[ object $fnull[ ,geo.unit]==geo.id,2]
-    feature_names <- names(object $newdata) [which(geo_check=="")]
-    new_data <- object $ newdata [index , geo_check =="" ]
+    baseline <- object$fnull[ object $fnull[ ,geo.unit]==geo.id,2]
+    feature_names <- names(object$newdata) [which(geo_check=="")]
+    new_data <- object$newdata [index, geo_check =="" ]
     
     # Compute mean and variance of posterior samples
     acomb <- function(...) abind(..., along = 3)
@@ -55,7 +77,7 @@ plot.Explainbarp <- function(x, average = NULL, type = NULL,  num_post= NULL,
     }
     
     for (i in seq_len(dim(phis.stats)[1L])) {  # loop through each observation
-      err <- object$ fx [ index ]- sum(phis.stats[i, 1L, ]) - object$fnull[object$fnull[,geo.unit] ==geo.id ,2]
+      err <- object$fx [ index ]- sum(phis.stats[i, 1L, ]) - object$fnull[object$fnull[,geo.unit] ==geo.id ,2]
       if( max(phis.stats[i, 2L, ])==0) {  v <- 0  } else {
         v <- (phis.stats[i, 2L, ] / max(phis.stats[i, 2L, ])) * 1e6 }
       adj <- err[i] * (v - (v * sum(v)) / (1 + sum(v)))
@@ -79,21 +101,21 @@ plot.Explainbarp <- function(x, average = NULL, type = NULL,  num_post= NULL,
     
     if (isTRUE(type =="bar")| is.null (type)){
       # bar plot
-      Local_mean <- as.data.frame(abs( phis_adj ))
+      Local_mean <- as.data.frame(abs(phis_adj))
       
       
-      sample_summary <-  local_obs $  long %>% filter (is.na (value)==F  )%>%
-        select(c("variable", "value"))%>% group_by(variable) %>% mutate (n=n() ) %>%
-        select (c("variable","n"))%>%distinct(.keep_all = T)
+      sample_summary <-  local_obs$long %>% filter (is.na (value)==F) %>%
+        select(c("variable", "value")) %>% group_by(variable) %>% mutate (n=n()) %>%
+        select (c("variable","n")) %>% distinct(.keep_all = T)
       
-      sample_zero <- local_obs $  long %>% filter (is.na (value)==F  )%>%
-        select(c("variable", "value"))%>% group_by(variable) %>% mutate (n=n() )%>%
+      sample_zero <- local_obs$long %>% filter (is.na (value)==F) %>%
+        select(c("variable", "value")) %>% group_by(variable) %>% mutate (n=n()) %>%
         filter(value==0) %>% mutate (zero =n()) %>% distinct(.keep_all = T) %>% select(c("variable", "zero"))
       
       sample_summary <- left_join(sample_summary, sample_zero, by = "variable" )
-      sample_summary [which( is.na(sample_summary$zero)), "zero"] <- 0
+      sample_summary [which(is.na(sample_summary$zero)), "zero"] <- 0
       
-      sample_summary$ percent <- paste0(sprintf("%.1f", round(sample_summary$zero/sample_summary$n*100, 1)) ,"%")
+      sample_summary$percent <- paste0(sprintf("%.1f", round(sample_summary$zero/sample_summary$n*100, 1)) ,"%")
       
       out <- bar_plot (Local_mean,probs = NULL, plot.flag = FALSE ,title  )
       ymin <-  (- diff(range(out$coordinates$limits$y)) * 0.02)
@@ -114,25 +136,17 @@ plot.Explainbarp <- function(x, average = NULL, type = NULL,  num_post= NULL,
   }
   else {
     
-    
-    if (isFALSE (adjust) & is.null(average)){
+     if ( isTRUE(average =="obs") ){
       
-      stop("If you want to calculate the average based on observations, enter 'obs'.",
-           "If you want to calculate the average based on the posterior sample, enter 'post'.",
-           "To compare the results based on observation and posterior sample, enter 'both'.",call. = FALSE)
+      new_data <- object$newdata [index, geo_check =="" ]
       
-    } else if ( isTRUE(average =="obs") ){
-      
-      
-      new_data <- object $ newdata [index , geo_check =="" ]
-      
-      temp_phis  <- foreach(i = 1 : length(object $ phis) ) %do% {
-        object $ phis[[i]][index,]
+      temp_phis  <- foreach(i = 1:length(object$phis)) %do% {
+        object$phis[[i]][index,]
       }
-      names (temp_phis) <- names (object $ phis)
+      names (temp_phis) <- names (object$phis)
       
       
-      for ( i in  names (temp_phis) ){
+      for ( i in names (temp_phis)){
         temp_i <- which ( new_data [,i] !=1)
         temp_phis[[i]][temp_i,] <- NA
         
@@ -140,10 +154,10 @@ plot.Explainbarp <- function(x, average = NULL, type = NULL,  num_post= NULL,
       
       
       # Average based on observation= #post by #variable
-      obs_mean_shap <- foreach(i = 1 : length(object $ phis), .combine = 'cbind' ) %do% {
+      obs_mean_shap <- foreach(i = 1 : length(object$phis), .combine = 'cbind') %do% {
         apply( temp_phis[[i]] , 2, function(x) {mean(abs(x),na.rm = T)})
       }
-      colnames(obs_mean_shap) <- names(object $ phis)
+      colnames(obs_mean_shap) <- names(object$phis)
       
       
       # Exclude cases where all values are not estimated.
@@ -160,15 +174,15 @@ plot.Explainbarp <- function(x, average = NULL, type = NULL,  num_post= NULL,
     } else if ( isTRUE(average =="post") ){
       if (is.null(num_post)){
         
-        new_data <- object $ newdata [index , geo_check =="" ]
+        new_data <- object$newdata [index, geo_check =="" ]
         
         # Average based on posterior sample = #obs by #variable
-        post_mean_shap <- foreach(i = 1: length(object $ phis), .combine = 'cbind' ) %do% {
-          apply(object $ phis[[i]][index,], 1, function(x) {mean( x) })
+        post_mean_shap <- foreach(i = 1: length(object$phis), .combine = 'cbind' ) %do% {
+          apply(object$phis[[i]][index,], 1, function(x) {mean(x)})
         }
-        colnames(post_mean_shap) <- names(object $ phis)
+        colnames(post_mean_shap) <- names(object$phis)
         
-        for ( i in colnames(post_mean_shap) ){
+        for ( i in colnames(post_mean_shap)){
           temp_i <- which ( new_data [,i] !=1)
           post_mean_shap[temp_i,i] <- NA
         }
@@ -178,25 +192,25 @@ plot.Explainbarp <- function(x, average = NULL, type = NULL,  num_post= NULL,
         
         
         # Change data format & mean values => local_total is List
-        local_total <- long_data (post_mean_shap, normalize = TRUE, absolute = TRUE)
+        local_total <- long_data(post_mean_shap, normalize = TRUE, absolute = TRUE)
         
         if (isTRUE(type =="bar")| is.null (type)){
           
           # bar plot
           Local_mean <- as.data.frame(abs(post_mean_shap))
           
-          sample_summary <-  local_total $  long %>% filter (is.na (value)==F  )%>%
-            select(c("variable", "value"))%>% group_by(variable) %>% mutate (n=n() ) %>%
-            select (c("variable","n"))%>%distinct(.keep_all = T)
+          sample_summary <-  local_total$long %>% filter (is.na (value)==F) %>%
+            select(c("variable", "value")) %>% group_by(variable) %>% mutate (n=n()) %>%
+            select (c("variable","n")) %>% distinct(.keep_all = T)
           
-          sample_zero <- local_total $  long %>% filter (is.na (value)==F  )%>%
-            select(c("variable", "value"))%>% group_by(variable) %>% mutate (n=n() )%>%
+          sample_zero <- local_total$long %>% filter (is.na (value)==F) %>%
+            select(c("variable", "value"))%>% group_by(variable) %>% mutate (n=n()) %>%
             filter(value==0) %>% mutate (zero =n()) %>% distinct(.keep_all = T) %>% select(c("variable", "zero"))
           
           sample_summary <- left_join(sample_summary, sample_zero, by = "variable" )
           sample_summary [which( is.na(sample_summary$zero)), "zero"] <- 0
           
-          sample_summary$ percent <- paste0(sprintf("%.1f", round(sample_summary$zero/sample_summary$n*100, 1)) ,"%")
+          sample_summary$percent <- paste0(sprintf("%.1f", round(sample_summary$zero/sample_summary$n*100, 1)) ,"%")
           
           
           out <- bar_plot (Local_mean, probs = NULL, plot.flag = FALSE,title  )
@@ -218,14 +232,13 @@ plot.Explainbarp <- function(x, average = NULL, type = NULL,  num_post= NULL,
         
       } else if (isFALSE (is.null(num_post)) ){
         
-        
         # num_post th posterior sample = #obs by #variable
-        obs <- foreach(i = 1: length(object $ phis), .combine = 'cbind' ) %do% {
-          object $ phis[[i]][index, num_post]
+        obs <- foreach(i = 1: length(object$phis), .combine = 'cbind') %do% {
+          object$phis[[i]][index, num_post]
         }
-        colnames(obs) <- names(object $ phis)
+        colnames(obs) <- names(object$phis)
         
-        new_data <- object $ newdata [index , geo_check =="" ]
+        new_data <- object$newdata [index, geo_check =="" ]
         
         for ( i in colnames(obs) ){
           temp_i <- which ( new_data [,i] !=1)
@@ -247,12 +260,12 @@ plot.Explainbarp <- function(x, average = NULL, type = NULL,  num_post= NULL,
           
           out <- bar_plot (abs(obs),probs =NULL, plot.flag = FALSE,title  )
           
-          sample_summary <-  local_obs $  long %>% filter (is.na (value)==F  )%>%
-            select(c("variable", "value"))%>% group_by(variable) %>% mutate (n=n() ) %>%
-            select (c("variable","n"))%>%distinct(.keep_all = T)
+          sample_summary <-  local_obs$long %>% filter (is.na (value)==F) %>%
+            select(c("variable", "value")) %>% group_by(variable) %>% mutate (n=n()) %>%
+            select (c("variable","n")) %>% distinct(.keep_all = T)
           
-          sample_zero <- local_obs $  long %>% filter (is.na (value)==F  )%>%
-            select(c("variable", "value"))%>% group_by(variable) %>% mutate (n=n() )%>%
+          sample_zero <- local_obs$long %>% filter (is.na (value)==F)%>%
+            select(c("variable", "value"))%>% group_by(variable) %>% mutate (n=n())%>%
             filter(value==0) %>% mutate (zero =n()) %>% distinct(.keep_all = T) %>% select(c("variable", "zero"))
           
           sample_summary <- left_join(sample_summary, sample_zero, by = "variable" )
@@ -273,12 +286,12 @@ plot.Explainbarp <- function(x, average = NULL, type = NULL,  num_post= NULL,
       
     }else if ( isTRUE(average =="both") ){
       
-      new_data <- object $ newdata [index , geo_check =="" ]
+      new_data <- object$newdata [index , geo_check =="" ]
       
-      temp_phis <-  foreach(i = 1 : length(object $ phis) ) %do% {
-        object $ phis[[i]][index,]
+      temp_phis <-  foreach(i = 1 : length(object$phis) ) %do% {
+        object$phis[[i]][index,]
       }
-      names (temp_phis) <- names (object $ phis)
+      names (temp_phis) <- names (object$phis)
       
       
       for ( i in  names (temp_phis) ){
@@ -288,10 +301,10 @@ plot.Explainbarp <- function(x, average = NULL, type = NULL,  num_post= NULL,
       }
       
       # Average based on observation= #post by #variable
-      obs_mean_shap <- as.data.frame( foreach(i = 1 : length(object $ phis), .combine = 'cbind' ) %do% {
+      obs_mean_shap <- as.data.frame( foreach(i = 1 : length(object$phis), .combine = 'cbind' ) %do% {
         apply( temp_phis[[i]] , 2, function(x) {mean(abs(x),na.rm = T)})
       })
-      colnames(obs_mean_shap) <- names(object $ phis)
+      colnames(obs_mean_shap) <- names(object$phis)
       
       # Exclude cases where all values are not estimated.
       obs_mean_shap <- obs_mean_shap[, colSums(is.na (obs_mean_shap)) != nrow(obs_mean_shap)]
@@ -299,22 +312,22 @@ plot.Explainbarp <- function(x, average = NULL, type = NULL,  num_post= NULL,
       mean_obs <- colMeans(obs_mean_shap) [order( colMeans(obs_mean_shap), decreasing = TRUE) ]
       mean_obs <- as.data.frame(mean_obs)
       names (mean_obs) <- "mean"
-      mean_obs$ Average <- "Observation"
-      mean_obs$ variable <- obs_variable <- rownames (mean_obs)
+      mean_obs$Average <- "Observation"
+      mean_obs$variable <- obs_variable <- rownames (mean_obs)
       
-      obs_mean_shap $ Average <- "Observation"
-      obs_mean_shap $ ID <-  rownames(obs_mean_shap)
+      obs_mean_shap$Average <- "Observation"
+      obs_mean_shap$ID <-  rownames(obs_mean_shap)
       
       
       
       # Average based on posterior sample = #obs by #variable
-      post_mean_shap <- as.data.frame(foreach(i = 1: length(object $ phis), .combine = 'cbind' ) %do% {
-        apply( object $ phis[[i]][index,] , 1, function(x) {abs(mean( x ) )})
+      post_mean_shap <- as.data.frame(foreach(i = 1: length(object$phis), .combine = 'cbind' ) %do% {
+        apply( object$phis[[i]][index,] , 1, function(x) {abs(mean(x))})
       })
-      colnames(post_mean_shap) <- names(object $ phis)
+      colnames(post_mean_shap) <- names(object$phis)
       
-      for ( i in colnames(post_mean_shap) ){
-        temp_i <- which ( new_data [,i] !=1)
+      for ( i in colnames(post_mean_shap)){
+        temp_i <- which (new_data [,i] !=1)
         post_mean_shap[temp_i,i] <- NA
       }
       
@@ -324,63 +337,63 @@ plot.Explainbarp <- function(x, average = NULL, type = NULL,  num_post= NULL,
       mean_post <- colMeans(post_mean_shap,na.rm = T) [order( colMeans(post_mean_shap,na.rm = T ), decreasing = TRUE) ]
       mean_post <- as.data.frame(mean_post)
       names (mean_post) <- "mean"
-      mean_post $ Average <- "Samples"
-      mean_post$ variable <- rownames (mean_post)
+      mean_post$Average <- "Samples"
+      mean_post$variable <- rownames (mean_post)
       
-      post_mean_shap$ Average <- "Samples"
-      post_mean_shap $ ID <- rownames(post_mean_shap)
+      post_mean_shap$Average <- "Samples"
+      post_mean_shap$ID <- rownames(post_mean_shap)
       
       
       total_mean_shap <- rbind (obs_mean_shap, post_mean_shap )
       
       total_long <- melt(total_mean_shap, id =c('ID',"Average"))
-      total_long $ Average_re <- fct_rev( total_long $ Average )
+      total_long$Average_re <- fct_rev( total_long$Average )
       
       mean_data <- rbind (mean_obs, mean_post)
-      mean_data  $ Average_re <- fct_rev( mean_data  $ Average)
+      mean_data$Average_re <- fct_rev( mean_data$Average)
       
-      data_list <- list(total_long = total_long, mean_data = mean_data  )
+      data_list <- list(total_long = total_long, mean_data = mean_data)
       
       
       if ( is.null (type) | isTRUE(type == "bees")) {
         
-        ymax <- max (data_list $ total_long$value, na.rm = T) * (1+0.001)
-        ymin <-  (- diff(range(data_list $ total_long$value, na.rm = T))*0.05)
+        ymax <- max (data_list$total_long$value, na.rm = T) * (1+0.001)
+        ymin <-  (- diff(range(data_list$total_long$value, na.rm = T))*0.05)
         
         range_p <- (ymax-ymin)*0.02
         
         
-        left_p <-  data_list $ total_long %>% filter (is.na (value)==F & Average_re=="Observation")%>%
-          ggplot(  aes(x= variable, y=value, fill= Average_re )) +
-          geom_boxplot() +coord_flip() + theme_bw(base_size = 11) +
+        left_p <-  data_list$total_long %>% filter (is.na (value)==F & Average_re=="Observation") %>%
+          ggplot(  aes(x= variable, y=value, fill= Average_re)) +
+          geom_boxplot() + coord_flip() + theme_bw(base_size = 11) +
           labs(fill = "", x="",y="Mean(|SHAP|)") +
           scale_x_discrete(limits = rev(obs_variable),
                            labels = rev(obs_variable))+
-          scale_fill_manual(values=c(  "#F8766D"))+
+          scale_fill_manual(values=c( "#F8766D"))+
           theme(legend.position =  c(0.8, 0.2), legend.background=element_blank()) + ylim(ymin, ymax )
         
         
-        sample_summary <-  data_list $ total_long %>% filter (is.na (value)==F  & Average_re=="Samples")%>%
-          select(c("variable", "value"))%>% group_by(variable) %>% mutate (n=n() ) %>%
-          select (c("variable","n"))%>%distinct(.keep_all = T)
+        sample_summary <-  data_list$total_long %>% filter (is.na (value)==F  & Average_re=="Samples") %>%
+          select(c("variable", "value")) %>% group_by(variable) %>% mutate (n=n()) %>%
+          select (c("variable","n")) %>% distinct(.keep_all = T)
         
-        sample_zero <- data_list $ total_long %>% filter (is.na (value)==F & Average_re=="Samples" )%>%
-          select(c("variable", "value"))%>% group_by(variable) %>% mutate (n=n() )%>%
+        sample_zero <- data_list$total_long %>% filter (is.na (value)==F & Average_re=="Samples" ) %>%
+          select(c("variable", "value")) %>% group_by(variable) %>% mutate (n=n()) %>%
           filter(value==0) %>% mutate (zero =n()) %>% distinct(.keep_all = T) %>% select(c("variable", "zero"))
         
         sample_summary <- left_join(sample_summary, sample_zero, by = "variable" )
         sample_summary [which( is.na(sample_summary$zero)), "zero"] <- 0
         
-        sample_summary $ percent <- paste0(sprintf("%.1f", round(sample_summary$zero/sample_summary$n*100, 1)) ,"%")
+        sample_summary$percent <- paste0(sprintf("%.1f", round(sample_summary$zero/sample_summary$n*100, 1)) ,"%")
         
-        right_p <-  data_list $ total_long %>% filter (is.na (value)==F & Average_re=="Samples")%>%
+        right_p <-  data_list$total_long %>% filter (is.na (value)==F & Average_re=="Samples")%>%
           ggplot(  aes(x= variable, y=value, fill= Average_re )) +
-          geom_boxplot() +coord_flip() + theme_bw(base_size = 11) +
+          geom_boxplot() + coord_flip() + theme_bw(base_size = 11) +
           labs(fill = "", x="",y="Mean(|SHAP|)") +
           scale_x_discrete(limits = rev(obs_variable),
                            labels = rev(obs_variable))+
-          scale_fill_manual(values=c(  "#00BFC4"))+
-          theme(legend.position =  c(0.8, 0.2), legend.background=element_blank()) + ylim(ymin, ymax )
+          scale_fill_manual(values=c( "#00BFC4"))+
+          theme(legend.position = c(0.8, 0.2), legend.background=element_blank()) + ylim(ymin, ymax )
         
         right_p <- right_p + annotate("text",x= sample_summary$variable,
                                       y =  - range_p,
@@ -394,12 +407,12 @@ plot.Explainbarp <- function(x, average = NULL, type = NULL,  num_post= NULL,
       }
 
     } else if (isTRUE(type == "bar")  ){
-       out <- ggplot( data_list $ mean_data, aes(x= variable, y= mean, fill =  Average_re )) +
+       out <- ggplot( data_list$mean_data, aes(x= variable, y= mean, fill =  Average_re )) +
         geom_bar( stat = "identity" , position="dodge") +coord_flip() + theme_bw(base_size = 11) +
-        scale_fill_manual(values=c( "#00BFC4","#F8766D"))+
+        scale_fill_manual(values=c("#00BFC4","#F8766D"))+
         labs(fill = "Criteria for average ", x="",y="Mean(|SHAP|)") +
         scale_x_discrete(limits = rev(obs_variable), labels = rev(obs_variable)) +
-        ylim(c(0,max( data_list $ mean_data$mean)  ))+
+        ylim(c(0,max( data_list$mean_data$mean) ))+
         geom_text(aes( label = sprintf("%.3f",round(mean,3)) ),
                   hjust ="inward",  size= 3.5, position = position_dodge(width=0.9))+
         theme(legend.position = "bottom")
